summaryrefslogtreecommitdiffstats
path: root/src/tdepowersave.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/tdepowersave.cpp')
-rw-r--r--src/tdepowersave.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/tdepowersave.cpp b/src/tdepowersave.cpp
index b9f6f1d..d214a3b 100644
--- a/src/tdepowersave.cpp
+++ b/src/tdepowersave.cpp
@@ -986,20 +986,20 @@ void tdepowersave::do_autosuspendWarn() {
/*!
* \b TQT_SLOT to send the related suspend command for autosuspend
* \param chancel boolean with info if the autosuspend should get canceled
* \return boolean with the result of the operation
* \retval true if successful
* \retval false if command not supported or on any other error
* \todo add check if the requested command is supported before send and
* add message for this case to tell that maybe changed config!
*/
-bool tdepowersave::do_autosuspend(bool chancel) {
+bool tdepowersave::do_autosuspend(bool cancel) {
kdDebugFuncIn(trace);
// TODO: check if this is really needed, it get called also on the suspend methodes
autoSuspend->stop();
- if (!chancel) {
+ if (!cancel) {
if(!settings->disableNotifications) {
KNotifyClient::event( this->winId(), "autosuspend_event",
i18n("System is going into suspend mode now"));
@@ -986,20 +986,20 @@ void tdepowersave::do_autosuspendWarn() {
/*!
* \b TQT_SLOT to send the related suspend command for autosuspend
- * \param chancel boolean with info if the autosuspend should get canceled
+ * \param cancel boolean with info if the autosuspend should get canceled
* \return boolean with the result of the operation
* \retval true if successful